@@ -4,6 +4,7 @@ from dataclasses import dataclass, replace
 from typing import Optional
 import numpy as np
 import logging
+
 logger = logging.getLogger(__name__)
 
 
@@ -22,13 +23,18 @@ class Ray:
         The wavelength in nanometers.
     is_alive : bool
         Indicates if the ray is not dead
+    travelled : float
+        Total propagation distance. This gets updated when when calling `propagate`.
+    source: float
+        Identifier of the light source of luminophore that emitted the ray.
     """
+
     position: tuple
     direction: tuple
     wavelength: Optional[float]
     is_alive: bool = True
     travelled: float = 0.0
-    source: object = None
+    source: Optional[str] = None
 
     def __repr__(self):
         position = "(" + ", ".join(["{:.2f}".format(x) for x in self.position]) + ")"
@@ -49,12 +55,14 @@ class Ray:
         ray will be moved backwards.
         """
         if not self.is_alive:
-            raise ValueError('Ray is not alive.')
+            raise ValueError("Ray is not alive.")
         new_position = np.array(self.position) + np.array(self.direction) * distance
         new_position = tuple(new_position.tolist())
-        new_ray = replace(self, position=new_position, travelled=self.travelled+distance)
+        new_ray = replace(
+            self, position=new_position, travelled=self.travelled + distance
+        )
         return new_ray
-    
+
     def representation(self, from_node: Node, to_node: Node) -> Ray:
         """ Representation of the ray in another coordinate system.
         
